(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15748,        451]*)
(*NotebookOutlinePosition[     16390,        473]*)
(*  CellTagsIndexPosition[     16346,        469]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Linear Regression", "Section"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell["\<\
First, let's create a data set which we would like to fit a straight line \
to\
\>", "Text"],

Cell[BoxData[{
    \(\(num = 20;\)\), "\[IndentingNewLine]", 
    \(\(dataset\  = \ {{1, 7.18437, 1.13691}, {2, 7.41171, 1.41883}, {3, 
            6.46758, 1.46121}, {4, 9.30980, 1.36427}, {5, 7.54707, 
            1.18999}, {6, 12.6665, 1.75589}, {7, 12.63065, 1.586572}, {8, 
            11.73464, 1.009831}, {9, 14.28273, 1.277198}, {10, 15.95493, 
            1.617627}, {11, 16.86929, 1.846311}, {12, 15.17158, 
            1.479319}, {13, 19.68491, 1.709392}, {14, 18.75987, 
            1.060488}, {15, 20.21733, 1.248179}, {16, 22.45007, 
            1.696217}, {17, 21.67026, 1.058186}, {18, 24.78354, 
            1.940323}, {19, 25.03960, 1.471614}, {20, 25.04889, 
            1.930492}};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(datasetplot\  = \ ErrorListPlot[dataset]\)}], "Input"],

Cell["Create the sums that we need:", "Text"],

Cell[BoxData[{
    \(sum\  = \ 
      Sum[1/Part[dataset, i, 3]^2, {i, 1, num}]\), "\[IndentingNewLine]", 
    \(sumt\  = \ 
      Sum[Part[dataset, i, 1]/Part[dataset, i, 3]^2, {i, 1, 
          num}]\), "\[IndentingNewLine]", 
    \(sumy\  = \ 
      Sum[Part[dataset, i, 2]/Part[dataset, i, 3]^2, {i, 1, 
          num}]\), "\[IndentingNewLine]", 
    \(sumtt\  = \ 
      Sum[Part[dataset, i, 1]^2/Part[dataset, i, 3]^2, {i, 1, 
          num}]\), "\[IndentingNewLine]", 
    \(sumty\  = \ 
      Sum[Part[dataset, i, 1]*Part[dataset, i, 2]/Part[dataset, i, 3]^2, {i, 
          1, num}]\), "\[IndentingNewLine]", 
    \(delta\  = \ sum*sumtt\  - \ sumt^2\)}], "Input"],

Cell["Create the linear regression model:", "Text"],

Cell[BoxData[{
    \(\(a\  = \ \((sumtt*sumy - sumt*sumty)\)/
          delta;\)\), "\[IndentingNewLine]", 
    \(\(b\  = \ \((sum*sumty - sumt*sumy)\)/
          delta;\)\), "\[IndentingNewLine]", 
    \(f[t_]\  = \ a\  + \ b*t\), "\[IndentingNewLine]", 
    \(model\  = \ Plot[f[t], {t, 0, num}]\)}], "Input"],

Cell[BoxData[
    \(Show[model, datasetplot, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\)], "Input"],

Cell["\<\
So, what if we did not have the error bars? Let's see what we would have:\
\>", "Text"],

Cell[BoxData[{
    \(\(datasetreduced\  = \ {{1, 7.18437}, {2, 7.41171}, {3, 6.46758}, {4, 
            9.30980}, {5, 7.54707}, {6, 12.6665}, {7, 12.63065}, {8, 
            11.73464}, {9, 14.28273}, {10, 15.95493}, {11, 16.86929}, {12, 
            15.17158}, {13, 19.68491}, {14, 18.75987}, {15, 20.21733}, {16, 
            22.45007}, {17, 21.67026}, {18, 24.78354}, {19, 25.03960}, {20, 
            25.04889}};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(datasetreducedplot\  = ListPlot[datasetreduced]\)}], "Input"],

Cell[BoxData[{
    \(sum\  = \ num\), "\[IndentingNewLine]", 
    \(sumt\  = \ 
      Sum[Part[datasetreduced, i, 1], {i, 1, num}]\), "\[IndentingNewLine]", 
    \(sumy\  = \ 
      Sum[Part[datasetreduced, i, 2], {i, 1, num}]\), "\[IndentingNewLine]", 
    \(sumtt\  = \ 
      Sum[Part[datasetreduced, i, 1]^2, {i, 1, 
          num}]\), "\[IndentingNewLine]", 
    \(sumty\  = \ 
      Sum[Part[datasetreduced, i, 1]*Part[datasetreduced, i, 2], {i, 1, 
          num}]\), "\[IndentingNewLine]", 
    \(delta\  = \ sum*sumtt\  - \ sumt^2\)}], "Input"],

Cell["Create the linear regression model:", "Text"],

Cell[BoxData[{
    \(\(a\  = \ \((sumtt*sumy - sumt*sumty)\)/
          delta;\)\), "\[IndentingNewLine]", 
    \(\(b\  = \ \((sum*sumty - sumt*sumy)\)/
          delta;\)\), "\[IndentingNewLine]", 
    \(f[t_]\  = \ a\  + \ b*t\), "\[IndentingNewLine]", 
    \(model\  = \ Plot[f[t], {t, 0, num}]\)}], "Input"],

Cell[BoxData[
    \(compplot\  = \ 
      Show[model, datasetreducedplot, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\)], "Input"],

Cell[CellGroupData[{

Cell["Error Estimation", "Subsubsection"],

Cell["\<\
How good is our fit? We can calculate the correlation coefficient to find \
out.\
\>", "Text"],

Cell[BoxData[{
    \(ybar\  = \ 
      Sum[Part[datasetreduced, i, 2], {i, 1, num}]/
        num\), "\[IndentingNewLine]", 
    \(tbar\  = \ 
      Sum[Part[datasetreduced, i, 1], {i, 1, num}]/
        num\), "\[IndentingNewLine]", 
    \(Rsquare\  = \ 
      Sum[\((f[Part[datasetreduced, i, 1]]\  - \ \ ybar)\)^2, {i, 1, num}]/
        Sum[\((Part[datasetreduced, i, 2] - \ \ ybar)\)^2, {i, 1, 
            num}]\)}], "Input"],

Cell[TextData[{
  "Since we calculate ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "to be about ",
  Cell[BoxData[
      \(TraditionalForm\`0.96~1\)]],
  ", we have confidence that the data actually represent a linear model, and \
the model represents the data well."
}], "Text"],

Cell["\<\
For the data set, we also can verify graphically that the model function goes \
through the
centroid of the data set.\
\>", "Text"],

Cell[BoxData[{
    \(center\  = \ 
      Graphics[Disk[{tbar, ybar}, 0.4]]\), "\[IndentingNewLine]", 
    \(Show[compplot, center, AspectRatio \[Rule] 1]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extrapolation", "Subsection"],

Cell["\<\
Once we have the model, we can use it to extrapolate. First, we need the \
variance in the data set:\
\>", "Text"],

Cell[BoxData[{
    \(Sum[\((Part[datasetreduced, i, 2]\  - \ \ f[
                Part[datasetreduced, i, 1]])\)^2, {i, 1, num}]/
      num\), "\[IndentingNewLine]", 
    \(\[Sigma]\  = \ Sqrt[%]\)}], "Input"],

Cell[BoxData[{
    \(sigmaplot1\  = \ 
      Plot[{f[t] + \[Sigma], f[t] - \[Sigma]}, {t, 0, num}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\), "\[IndentingNewLine]", 
    \(sigmaplot2\  = \ 
      Plot[{f[t] + 2  \[Sigma], f[t] - 2  \[Sigma]}, {t, 0, num}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\)}], "Input"],

Cell[BoxData[{
    \(Show[sigmaplot1, datasetreducedplot]\), "\[IndentingNewLine]", 
    \(Show[sigmaplot2, datasetreducedplot]\)}], "Input"],

Cell[BoxData[
    \(f[25]\)], "Input"],

Cell[CellGroupData[{

Cell["Outlier", "Subsubsection"],

Cell["Here is a data set which contains an outlier:", "Text"],

Cell[BoxData[{
    \(\(datasetoutlier\  = \ {{1, 7.18437}, {2, 7.41171}, {3, 6.46758}, {4, 
            9.30980}, {5, 7.54707}, {6, 12.6665}, {7, 12.63065}, {8, 
            11.73464}, {9, 14.28273}, {10, 15.95493}, {11, 16.86929}, {12, 
            15.17158}, {13, 19.68491}, {14, 18.75987}, {15, 20.21733}, {16, 
            42.45007}, {17, 21.67026}, {18, 24.78354}, {19, 25.03960}, {20, 
            25.04889}};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(datasetoutlierplot\  = ListPlot[datasetoutlier]\)}], "Input"],

Cell[BoxData[{
    \(sum\  = \ num\), "\[IndentingNewLine]", 
    \(sumt\  = \ 
      Sum[Part[datasetoutlier, i, 1], {i, 1, num}]\), "\[IndentingNewLine]", 
    \(sumy\  = \ 
      Sum[Part[datasetoutlier, i, 2], {i, 1, num}]\), "\[IndentingNewLine]", 
    \(sumtt\  = \ 
      Sum[Part[datasetoutlier, i, 1]^2, {i, 1, 
          num}]\), "\[IndentingNewLine]", 
    \(sumty\  = \ 
      Sum[Part[datasetoutlier, i, 1]*Part[datasetoutlier, i, 2], {i, 1, 
          num}]\), "\[IndentingNewLine]", 
    \(delta\  = \ sum*sumtt\  - \ sumt^2\)}], "Input"],

Cell["Create the linear regression model:", "Text"],

Cell[BoxData[{
    \(\(a\  = \ \((sumtt*sumy - sumt*sumty)\)/
          delta;\)\), "\[IndentingNewLine]", 
    \(\(b\  = \ \((sum*sumty - sumt*sumy)\)/
          delta;\)\), "\[IndentingNewLine]", 
    \(f[t_]\  = \ a\  + \ b*t\), "\[IndentingNewLine]", 
    \(model\  = \ Plot[f[t], {t, 0, num}]\)}], "Input"],

Cell[BoxData[
    \(compplot\  = \ 
      Show[model, datasetoutlierplot, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\)], "Input"],

Cell[BoxData[{
    \(ybar\  = \ 
      Sum[Part[datasetoutlier, i, 2], {i, 1, num}]/
        num\), "\[IndentingNewLine]", 
    \(tbar\  = \ 
      Sum[Part[datasetoutlier, i, 1], {i, 1, num}]/
        num\), "\[IndentingNewLine]", 
    \(Rsquare\  = \ 
      Sum[\((f[Part[datasetoutlier, i, 1]]\  - \ \ ybar)\)^2, {i, 1, num}]/
        Sum[\((Part[datasetoutlier, i, 2] - \ \ ybar)\)^2, {i, 1, 
            num}]\)}], "Input"],

Cell[TextData[{
  "We see that ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  "has been significantly reduced, to the point where we would question \
whether our model actually represents the data."
}], "Text"],

Cell["\<\
We can identify any outliers by computing \[Sigma] and looking for data \
points which are more that 2\[Sigma] away from the model function\
\>", "Text"],

Cell[BoxData[{
    \(\(Sum[\((Part[datasetoutlier, i, 2]\  - \ \ f[
                  Part[datasetoutlier, i, 1]])\)^2, {i, 1, num}]/
        num;\)\), "\[IndentingNewLine]", 
    \(\[Sigma]\  = \ Sqrt[%]\), "\[IndentingNewLine]", 
    \(\(Table[\ {i, 
          Abs[Part[datasetoutlier, i, 2]\  - \ \ f[
                  Part[datasetoutlier, i, 1]]\ ] - 2  \[Sigma]}, {i, 1, 
          num}]\ ;\)\), "\[IndentingNewLine]", 
    \(TableForm[%]\)}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Package"
}], "Section"],

Cell[TextData[{
  "Here is the linear regression package that comes with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". It does not encorporate the variance in each data point into the \
result."
}], "Text"],

Cell[BoxData[
    \(<< Statistics`LinearRegression`\)], "Input"],

Cell[BoxData[
    \(func[t_] = Fit[datasetreduced, {1, t}, t]\)], "Input"],

Cell[BoxData[
    \(regress = 
      Regress[datasetreduced, {1, t}, t, 
        RegressionReport \[Rule] {RSquared, EstimatedVariance}]\)], "Input"],

Cell["\<\
Also, the regression package can help you identify outliers using certain \
options.\
\>", "Text"],

Cell[BoxData[
    \(regress = 
      Regress[datasetoutlier, {1, t}, t, 
        RegressionReport \[Rule] {RSquared, \ AdjustedRSquared, CookD, 
            PredictedResponseDelta}]\)], "Input"],

Cell[CellGroupData[{

Cell["Other Linear Regressions", "Subsection"],

Cell[BoxData[{
    \(data\  = {{0, 0.8473611502101435`}, {1, 0.16105078349847718`}, {2, 
          0.20997883486648275`}, {3, 0.5767222628194963`}, {4, 
          0.5330677559974459`}, {5, 0.7952707369812955`}, {6, 
          1.3787728263000383`}, {7, 2.0967707251295673`}, {8, 
          2.4469367135495617`}, {9, 2.7132851501919975`}, {10, 
          3.2699381172959363`}, {11, 4.595205603363667`}, {12, 
          5.268725083591067`}, {13, 5.52998002589335`}, {14, 
          6.693769672612626`}, {15, 7.735026034961229`}, {16, 
          8.039438338264981`}, {17, 9.02567289313276`}, {18, 
          10.644595538713753`}, {19, 11.48472079795253`}, {20, 
          12.540262324455885`}}\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(dataplot\  = \ 
      ListPlot[data, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\)}], "Input"],

Cell[BoxData[{
    \(sumtttt\  = \ 
      Sum[Part[data, i, 1]^4, {i, 1, num}]\), "\[IndentingNewLine]", 
    \(sumtty\  = \ 
      Sum[Part[data, i, 1]^2*Part[data, i, 2], {i, 1, num}]\)}], "Input"],

Cell["Create the linear regression model:", "Text"],

Cell[BoxData[{
    \(a\  = \ sumtty/sumtttt\), "\[IndentingNewLine]", 
    \(f[t_]\  = \ a\ t^2\), "\[IndentingNewLine]", 
    \(model\  = \ Plot[f[t], {t, 0, num}]\)}], "Input"],

Cell[BoxData[
    \(Show[dataplot, model]\)], "Input"],

Cell[BoxData[{
    \(\(Sum[\((Part[data, i, 2]\  - \ \ f[Part[data, i, 1]])\)^2, {i, 1, 
            num}]/num;\)\), "\[IndentingNewLine]", 
    \(\[Sigma]\  = \ Sqrt[%]\)}], "Input"],

Cell[BoxData[{
    \(sigmaplot1\  = \ 
      Plot[{f[t] + \[Sigma], f[t] - \[Sigma]}, {t, 0, num}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\), "\[IndentingNewLine]", 
    \(sigmaplot2\  = \ 
      Plot[{f[t] + 2  \[Sigma], f[t] - 2  \[Sigma]}, {t, 0, num}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\), "\[IndentingNewLine]", 
    \(Show[sigmaplot1, dataplot]\), "\[IndentingNewLine]", 
    \(Show[sigmaplot2, dataplot]\)}], "Input"],

Cell[BoxData[
    \(regress = 
      Regress[data, {1, t^2}, t, 
        RegressionReport \[Rule] {RSquared, EstimatedVariance}]\)], "Input"],

Cell[CellGroupData[{

Cell["Even More Complicated Linear Regressions", "Subsubsection"],

Cell[BoxData[{
    \(data\  = {{0, 0.9043053159257124`}, {1, 8.097719084832498`}, {2, 
          6.810410294461815`}, {3, 4.632220192987015`}, {4, 
          1.1930723603688511`}, {5, \(-6.9574464964662495`\)}, {6, \
\(-5.587182715575544`\)}, {7, \(-8.665349845871182`\)}, {8, \
\(-5.073494692438124`\)}, {9, \(-2.3556203180876514`\)}, {10, 
          2.0381891304623627`}, {11, 8.480559042670984`}, {12, 
          6.550866749461399`}, {13, 
          6.065564057766881`}, {14, \(-0.6241447915657803`\)}, {15, \
\(-3.1268931737277605`\)}, {16, \(-5.2256818877843525`\)}, {17, \
\(-7.323617407348574`\)}, {18, \(-5.469564117752752`\)}, {19, \
\(-2.1255226709689263`\)}, {20, 
          4.496401897197252`}}\), "\[IndentingNewLine]", 
    \(dataplot\  = \ 
      ListPlot[data, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y\>"}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(func[t_] = 
      Fit[data, {Cos[0.2  Pi\ t], Sin[0.2  Pi\ t]}, 
        t]\), "\[IndentingNewLine]", 
    \(funcplot\  = \ Plot[func[t], {t, 0, 20}]\)}], "Input"],

Cell[BoxData[
    \(Show[dataplot, funcplot]\)], "Input"],

Cell[BoxData[
    \(regress = 
      Regress[data, {1, Cos[0.2  Pi\ t], \ Sin[0.2  Pi\ t]}, t, 
        RegressionReport \[Rule] {RSquared, EstimatedVariance}]\)], "Input"],

Cell[BoxData[{
    \(data\  = \ 
      Table[\ {i, 3/100  i^2 + Random[Real, {0, 1}]}, {i, 0, 
          20}]\), "\[IndentingNewLine]", 
    \(ListPlot[data]\)}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 991}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 36, 0, 59, "Section"],
Cell[1766, 54, 54, 1, 30, "Input"],
Cell[1823, 57, 102, 3, 33, "Text"],
Cell[1928, 62, 810, 12, 270, "Input"],
Cell[2741, 76, 45, 0, 33, "Text"],
Cell[2789, 78, 673, 15, 230, "Input"],
Cell[3465, 95, 51, 0, 33, "Text"],
Cell[3519, 97, 311, 6, 90, "Input"],
Cell[3833, 105, 123, 2, 50, "Input"],
Cell[3959, 109, 97, 2, 33, "Text"],
Cell[4059, 113, 531, 7, 190, "Input"],
Cell[4593, 122, 553, 12, 170, "Input"],
Cell[5149, 136, 51, 0, 33, "Text"],
Cell[5203, 138, 311, 6, 90, "Input"],
Cell[5517, 146, 154, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[5696, 153, 41, 0, 43, "Subsubsection"],
Cell[5740, 155, 104, 3, 33, "Text"],
Cell[5847, 160, 428, 10, 130, "Input"],
Cell[6278, 172, 290, 9, 52, "Text"],
Cell[6571, 183, 141, 4, 52, "Text"],
Cell[6715, 189, 167, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6919, 197, 35, 0, 47, "Subsection"],
Cell[6957, 199, 124, 3, 52, "Text"],
Cell[7084, 204, 209, 4, 90, "Input"],
Cell[7296, 210, 383, 8, 90, "Input"],
Cell[7682, 220, 141, 2, 50, "Input"],
Cell[7826, 224, 38, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[7889, 229, 32, 0, 43, "Subsubsection"],
Cell[7924, 231, 61, 0, 33, "Text"],
Cell[7988, 233, 531, 7, 190, "Input"],
Cell[8522, 242, 553, 12, 170, "Input"],
Cell[9078, 256, 51, 0, 33, "Text"],
Cell[9132, 258, 311, 6, 90, "Input"],
Cell[9446, 266, 154, 3, 50, "Input"],
Cell[9603, 271, 428, 10, 130, "Input"],
Cell[10034, 283, 219, 6, 52, "Text"],
Cell[10256, 291, 163, 3, 52, "Text"],
Cell[10422, 296, 458, 9, 210, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10941, 312, 95, 4, 59, "Section"],
Cell[11039, 318, 220, 6, 52, "Text"],
Cell[11262, 326, 64, 1, 30, "Input"],
Cell[11329, 329, 74, 1, 30, "Input"],
Cell[11406, 332, 149, 3, 50, "Input"],
Cell[11558, 337, 108, 3, 33, "Text"],
Cell[11669, 342, 194, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[11888, 350, 46, 0, 47, "Subsection"],
Cell[11937, 352, 860, 14, 290, "Input"],
Cell[12800, 368, 199, 4, 70, "Input"],
Cell[13002, 374, 51, 0, 33, "Text"],
Cell[13056, 376, 178, 3, 70, "Input"],
Cell[13237, 381, 54, 1, 30, "Input"],
Cell[13294, 384, 183, 3, 70, "Input"],
Cell[13480, 389, 503, 10, 130, "Input"],
Cell[13986, 401, 141, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[14152, 408, 65, 0, 43, "Subsubsection"],
Cell[14220, 410, 892, 16, 290, "Input"],
Cell[15115, 428, 184, 4, 50, "Input"],
Cell[15302, 434, 57, 1, 30, "Input"],
Cell[15362, 437, 172, 3, 50, "Input"],
Cell[15537, 442, 171, 4, 70, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

