(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14867,        370]*)
(*NotebookOutlinePosition[     15512,        392]*)
(*  CellTagsIndexPosition[     15468,        388]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Note, you may not have the ExtendGraphics package installed to be able to \
label contour plots. \
http://support.wolfram.com/applicationpacks/unsupported/extend/\
\>", "Text"],

Cell[BoxData[{
    \(<< ExtendGraphics`LabelContour`\), "\[IndentingNewLine]", 
    \(<< Graphics`ImplicitPlot`\), "\[IndentingNewLine]", 
    \(<< Graphics`FilledPlot`\)}], "Input"],

Cell[BoxData[{
    \(f[x_, 
        y_]\  = \ \((x + y - 1/4)\)\ Exp[\(-x^2\) - 
            y^2]\), "\[IndentingNewLine]", 
    \(\(\(g[x_, 
        y]\  = \ \((x - 1/2)\)^2 + \((y - 1/3)\)^2\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Plot3D[f[x, y], {x, \(-2\), 2}, {y, \(-3\), 3}, 
      AxesLabel \[Rule] {x, y, z}, PlotPoints \[Rule] 35, 
      ColorFunction \[Rule] Hue, 
      PlotRange \[Rule] {\(-1\)/2, 1/2}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(plot\  = \ 
      ContourPlot[f[x, y], {x, \(-1\), 2}, {y, \(-1\), 2}, 
        Contours \[Rule] 9, PlotPoints \[Rule] 40, FrameLabel \[Rule] {x, y}, 
        ContourShading \[Rule] False]\), "\[IndentingNewLine]", 
    \(plot2\  = \ 
      ImplicitPlot[g[x, y] \[Equal] 1, {x, \(-1\), 2}, 
        PlotStyle \[Rule] {Hue[h], 
            Dashing[{0.05, 0.05}]}]\), "\[IndentingNewLine]", 
    \(plot3\  = \ LabelContourLines[plot]\), "\[IndentingNewLine]", 
    \(\(\(Show[plot3, plot2]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(Plot[{x, x^2/2 + 1/2, \(+x^8\)/8 + 7/8}, {x, 0, 2}, Frame \[Rule] True, 
      Axes \[Rule] False, FrameTicks \[Rule] False, 
      PlotStyle \[Rule] {{Hue[0.6]}, {Hue[0]}, {Hue[0]}}]\)], "Input"],

Cell[BoxData[
    \(Simplify[D[g[x, y], x]]\)], "Input"],

Cell[BoxData[
    \(Solve[g[x, y] \[Equal] 1, x]\)], "Input"],

Cell[BoxData[{
    \(Eliminate[{D[f[x, y], x] \[Equal] LM\ D[g[x, y], x], 
        D[f[x, y], y] \[Equal] LM\ D[g[x, y], y], g[x, y] \[Equal] 1}, 
      LM]\), "\[IndentingNewLine]", 
    \(\(Solve[{%}, {x, y}];\)\), "\[IndentingNewLine]", 
    \(N[%]\), "\[IndentingNewLine]", 
    \(TeXForm[%]\)}], "Input"],

Cell[BoxData[
    \(f[0.107593, 1.25313]\)], "Input"],

Cell[BoxData[{
    \(\(f[x_, 
          y_]\  = \ \((x + y - 1/4)\)\ Exp[\(-x^2\) - 
              y^2];\)\), "\[IndentingNewLine]", 
    \(\(g[x_, 
          y]\  = \ \((x - 1/2)\)^2 + \((y - 
                1/3)\)^2;\)\), "\[IndentingNewLine]", 
    \(plot\  = \ 
      ContourPlot[f[x, y], {x, \(-1\), 3/2}, {y, \(-1\), 2}, 
        Contours \[Rule] {\(-0.76\), \(-0.70\), \(-0.61\), \(-0.52\), 0.03, 
            0.12, 0.23, 0.31, 0.40}, PlotPoints \[Rule] 40, 
        FrameLabel \[Rule] {x, y}, 
        ContourShading \[Rule] False]\), "\[IndentingNewLine]", 
    \(plot2\  = \ 
      ImplicitPlot[g[x, y] \[Equal] 1, {x, \(-1\), 3/2}, 
        PlotStyle \[Rule] {Hue[h], Dashing[{0.05, 0.05}]}, 
        Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {x, 
            y}]\), "\[IndentingNewLine]", 
    \(plot3\  = \ LabelContourLines[plot]\), "\[IndentingNewLine]", 
    \(disk1\  = \ 
      Graphics[Disk[{0.11, 1.25}, 0.04]]\), "\[IndentingNewLine]", 
    \(disk2\  = \ 
      Graphics[Disk[{\(-0.26\), \(-0.31\)}, 0.04]]\), "\[IndentingNewLine]", 
    \(\(\(Show[plot2, disk1, disk2, plot3, disk2, 
      PlotRange \[Rule] {\(-1.0\), 1.5}, 
      AspectRatio \[Rule] 1]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(f[x_, y_, z_, t_]\  = \ 
      x^2 + y^2 + z^2 + t^2\), "\[IndentingNewLine]", 
    \(Solve[{D[f[x, y, z, t], x] \[Equal] 0, D[f[x, y, z, t], y] \[Equal] 0, 
        D[f[x, y, z, t], z] \[Equal] 0, D[f[x, y, z, t], t] \[Equal] 0}, {x, 
        y, z, t}]\)}], "Input"],

Cell[BoxData[{
    \(Clear[x, y, z, t, LM1, LM2]\), "\[IndentingNewLine]", 
    \(f[x_, y_, z_, t_]\  = \ 
      x^2 + y^2 + z^2 + t^2\), "\[IndentingNewLine]", 
    \(g1[x_, y_, z_, t_]\  = \ x - z\), "\[IndentingNewLine]", 
    \(\(\(g2[x_, y_, z_, t_]\  = \ y^2 + t\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(eq1\  = \ 
      D[f[x, y, z, t], x] \[Equal] 
        LM1\ D[g1[x, y, z, t], x] + 
          LM2\ D[g2[x, y, z, t], x]\), "\[IndentingNewLine]", 
    \(eq2\  = \ 
      D[f[x, y, z, t], y] \[Equal] 
        LM1\ D[g1[x, y, z, t], y] + 
          LM2\ D[g2[x, y, z, t], y]\), "\[IndentingNewLine]", 
    \(eq3\  = \ 
      D[f[x, y, z, t], z] \[Equal] 
        LM1\ D[g1[x, y, z, t], z] + 
          LM2\ D[g2[x, y, z, t], z]\), "\[IndentingNewLine]", 
    \(eq4\  = \ 
      D[f[x, y, z, t], t] \[Equal] 
        LM1\ D[g1[x, y, z, t], t] + 
          LM2\ D[g2[x, y, z, t], t]\), "\[IndentingNewLine]", 
    \(eq5\  = \ g1[x, y, z, t] \[Equal] 2\), "\[IndentingNewLine]", 
    \(eq6\  = \ g2[x, y, z, t] \[Equal] 4\), "\[IndentingNewLine]", 
    \(\(\(Eliminate[{eq1, eq2, eq3, eq4, eq5, eq6}, {LM1, 
        LM2}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Solve[{D[f[x, y, z, t], x] \[Equal] 
          LM1\ D[g1[x, y, z, t], x] + 
            LM2\ D[g2[x, y, z, t], x], \[IndentingNewLine]D[f[x, y, z, t], 
            y] \[Equal] 
          LM1\ D[g1[x, y, z, t], y] + 
            LM2\ D[g2[x, y, z, t], y], \[IndentingNewLine]D[f[x, y, z, t], 
            z] \[Equal] 
          LM1\ D[g1[x, y, z, t], z] + 
            LM2\ D[g2[x, y, z, t], z], \[IndentingNewLine]D[f[x, y, z, t], 
            t] \[Equal] 
          LM1\ D[g1[x, y, z, t], t] + 
            LM2\ D[g2[x, y, z, t], t], \[IndentingNewLine]g1[x, y, z, 
            t] \[Equal] 2, g2[x, y, z, t] \[Equal] 4}, {x, y, z, t, LM1, 
        LM2}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(f[1, Sqrt[7/2], \(-1\), 1/2]\)], "Input"],

Cell[BoxData[
    \(N[%]\)], "Input"],

Cell[TextData[{
  "Here is how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can solve the TV problem in Chapter 2, both unconstrained and \
constrained."
}], "Text"],

Cell[BoxData[{
    \(Clear[x, y, f, LM1]\), "\[IndentingNewLine]", 
    \(\(\(f[x_, 
        y_]\  = \ \((339\  - \ 0.01\ x\  - 0.003\ y)\)\ x\  + \ \((399\  - \ 
              0.004\ x\  - \ 0.01\ y)\)\ y\  - \ \((400000 + 195  x + 
            225  y)\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Solve[{D[f[x, y], x] \[Equal] 0, D[f[x, y], y] \[Equal] 0}, {x, 
        y}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Clear[x, y, LM1]\), "\[IndentingNewLine]", 
    \(g1[x_, y_]\  = \ x\), "\[IndentingNewLine]", 
    \(\(\(Solve[{D[f[x, y], x] \[Equal] LM1\ D[g1[x, y], x], 
        D[f[x, y], y] \[Equal] LM1\ D[g1[x, y], y], 
        g1[x, y] \[Equal] 5000}, {x, y, LM1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Clear[x, y, LM1]\), "\[IndentingNewLine]", 
    \(g1[x_, y_]\  = \ y\), "\[IndentingNewLine]", 
    \(\(\(Solve[{D[f[x, y], x] \[Equal] LM1\ D[g1[x, y], x], 
        D[f[x, y], y] \[Equal] LM1\ D[g1[x, y], y], 
        g1[x, y] \[Equal] 8000}, {x, y, LM1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Clear[x, y, LM1]\), "\[IndentingNewLine]", 
    \(g1[x_, y_]\  = \ x + y\), "\[IndentingNewLine]", 
    \(\(\(Solve[{D[f[x, y], x] \[Equal] LM1*D[g1[x, y], x], 
        D[f[x, y], y] \[Equal] LM1*D[g1[x, y], y], 
        g1[x, y] \[Equal] 10000}, {x, y, LM1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Clear[x, y, LM1]\), "\[IndentingNewLine]", 
    \(g1[x_, y_]\  = \ x\), "\[IndentingNewLine]", 
    \(\(\(Solve[{D[f[x, y], x] \[Equal] LM1*D[g1[x, y], x], 
        D[f[x, y], y] \[Equal] LM1*D[g1[x, y], y], g1[x, y] \[Equal] 0}, {x, 
        y, LM1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Clear[x, y, LM1]\), "\[IndentingNewLine]", 
    \(g1[x_, y_]\  = \ y\), "\[IndentingNewLine]", 
    \(Solve[{D[f[x, y], x] \[Equal] LM1*D[g1[x, y], x], 
        D[f[x, y], y] \[Equal] LM1*D[g1[x, y], y], g1[x, y] \[Equal] 0}, {x, 
        y, LM1}]\)}], "Input"],

Cell[BoxData[
    \(<< Miscellaneous`RealOnly`\)], "Input"],

Cell[BoxData[{
    \(f[x_, y_, 
        z_]\  = \((\ 
            40\  - \ x/100 + \ a\ y/100)\)\ \ x\  - \ \((45\  - \ 
              5  x/100)\)\ y\  + 3  z/100\), "\[IndentingNewLine]", 
    \(\(\(g[x_, y_, z_]\  = \ 4  x + y + z\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(D[f[x, y, z], x]\), "\[IndentingNewLine]", 
    \(D[f[x, y, z], y]\), "\[IndentingNewLine]", 
    \(\(\(D[f[x, y, z], z]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(D[g[x, y, z], x]\), "\[IndentingNewLine]", 
    \(D[g[x, y, z], y]\), "\[IndentingNewLine]", 
    \(\(\(D[g[x, y, z], z]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(sol\  = \ 
        Solve[{D[f[x, y, z], x] \[Equal] LM\ D[g[x, y, z], x], 
            D[f[x, y, z], y] \[Equal] LM\ D[g[x, y, z], y], 
            D[f[x, y, z], z] \[Equal] LM\ D[g[x, y, z], z], 
            g[x, y, z] \[Equal] 10}, {x, y, z, 
            LM}];\)\), "\[IndentingNewLine]", 
    \(Simplify[sol]\), "\[IndentingNewLine]", 
    \(N[%]\), "\[IndentingNewLine]", 
    \(TeXForm[sol]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(z = \(2\ \((\(-39438\) - 6962\ a + 5\ a\^2)\)\)\/\((5 + a)\)\^2\), "\
\[IndentingNewLine]", 
    \(y = \(-\(\(2\ \((5467 + 
                  1994\ a)\)\)\/\((5 + a)\)\^2\)\)\), "\[IndentingNewLine]", 
    \(x = 4503\/\(5 + a\)\)}], "Input"],

Cell[BoxData[{
    \(Plot[x, {a, \(-10\), 10}, 
      PlotRange \[Rule] {\(-10000\), 10000}]\), "\[IndentingNewLine]", 
    \(Plot[y, {a, \(-10\), 10}]\), "\[IndentingNewLine]", 
    \(Plot[z, {a, \(-10\), 10}]\), "\[IndentingNewLine]", 
    \(Plot[f[x, y, z], {a, \(-10\), 10}]\)}], "Input"],

Cell[BoxData[{
    \(Sensx[a_]\  = \ Simplify[D[x, a]\ a/x]\), "\[IndentingNewLine]", 
    \(Sensy[a_]\  = \ Simplify[D[y, a]\ a/y]\), "\[IndentingNewLine]", 
    \(Sensz[a_]\  = \ Simplify[D[z, a]\ a/z]\), "\[IndentingNewLine]", 
    \(Sensf[a_]\  = \ 
      Simplify[D[f[x, y, z], a]\ a/f[x, y, z]]\), "\[IndentingNewLine]", 
    \(TeXForm[Sensf[\[Alpha]]]\)}], "Input"],

Cell[BoxData[{
    \(Plot[Sensx[a], {a, \(-10\), 10}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<a\>", "\<Sensitivity of Optimal x\>"}, 
      PlotRange \[Rule] {\(-60\), 50}]\), "\[IndentingNewLine]", 
    \(Plot[Sensy[a], {a, \(-10\), 10}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<a\>", "\<Sensitivity of Optimal y\>"}, 
      PlotRange \[Rule] {\(-60\), 50}]\), "\[IndentingNewLine]", 
    \(Plot[Sensz[a], {a, \(-10\), 10}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<a\>", "\<Sensitivity of Optimal z\>"}, 
      PlotRange \[Rule] {\(-60\), 50}]\), "\[IndentingNewLine]", 
    \(Plot[Sensf[a], {a, \(-10\), 10}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<a\>", "\<Sensitivity of Maximum f\>"}, 
      PlotRange \[Rule] {\(-60\), 50}]\)}], "Input"],

Cell[BoxData[
    \(Sensf[6. ]\)], "Input"],

Cell[CellGroupData[{

Cell["Example 2.5", "Section"],

Cell["\<\
Here I create the plots for the examples in Chapter 2. Remember, you may not \
have the LabelContour package on your computer, so you won;t be able to label \
the contours.

I created this mainly for the last plot, to show what it looks like when you \
get a maximum at the intersection of two contraint curves.\
\>", "Text"],

Cell[BoxData[
    \(Clear[x, y, z]\)], "Input"],

Cell[BoxData[{
    \(f[x_, 
        y_]\  = \ \((339 - 0.01  x - 0.003  y)\) 
          x + \((399 - 0.004  x - 0.01  y)\) 
          y - \((400000 + 195  x + 225  y)\)\), "\[IndentingNewLine]", 
    \(region[x_]\  = \ 
      If[x < 5000, If[x < 2000, 8000, 10000 - x], 
        0]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(constraint\  = \ 
      FilledPlot[region[x], {x, 0, 8000}, 
        PlotRange \[Rule] {0, 
            12000}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(plot1\  = \ 
      ContourPlot[f[x, y], {x, 0, 8000}, {y, 0, 12000}, 
        Contours \[Rule] {300000, 400000, 532308, 550000}, 
        PlotPoints \[Rule] 40, FrameLabel \[Rule] {x, y}, 
        ContourShading \[Rule] False]\), "\[IndentingNewLine]", 
    \(plot3\  = \ 
      LabelContourLines[plot1]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[constraint, plot3]\)}], "Input"],

Cell[BoxData[{
    \(f[x_, 
        y_]\  = \ \((339 - 0.01  x - 0.003  y)\) 
          x + \((399 - 0.004  x - 0.01  y)\) 
          y - \((400000 + 195  x + 225  y)\)\), "\[IndentingNewLine]", 
    \(region[x_]\  = \ 
      If[x < 3000, If[x < 2000, 8000, 10000 - x], 
        0]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(constraint\  = \ 
      FilledPlot[region[x], {x, 0, 8000}, 
        PlotRange \[Rule] {0, 
            12000}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(plot1\  = \ 
      ContourPlot[f[x, y], {x, 0, 8000}, {y, 0, 12000}, 
        Contours \[Rule] {300000, 400000, f[3000, 7000], 550000}, 
        PlotPoints \[Rule] 40, FrameLabel \[Rule] {x, y}, 
        ContourShading \[Rule] False]\), "\[IndentingNewLine]", 
    \(plot3\  = \ 
      LabelContourLines[plot1]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[constraint, plot3]\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{Automatic, 182}, {30, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 186, 4, 52, "Text"],
Cell[1894, 56, 182, 3, 70, "Input"],
Cell[2079, 61, 1077, 23, 330, "Input"],
Cell[3159, 86, 216, 3, 70, "Input"],
Cell[3378, 91, 56, 1, 30, "Input"],
Cell[3437, 94, 61, 1, 30, "Input"],
Cell[3501, 97, 309, 6, 110, "Input"],
Cell[3813, 105, 53, 1, 30, "Input"],
Cell[3869, 108, 1284, 28, 350, "Input"],
Cell[5156, 138, 288, 5, 90, "Input"],
Cell[5447, 145, 1918, 42, 590, "Input"],
Cell[7368, 189, 61, 1, 30, "Input"],
Cell[7432, 192, 37, 1, 30, "Input"],
Cell[7472, 195, 179, 6, 52, "Text"],
Cell[7654, 203, 2014, 38, 710, "Input"],
Cell[9671, 243, 59, 1, 30, "Input"],
Cell[9733, 246, 1115, 24, 410, "Input"],
Cell[10851, 272, 262, 5, 118, "Input"],
Cell[11116, 279, 292, 5, 90, "Input"],
Cell[11411, 286, 372, 6, 110, "Input"],
Cell[11786, 294, 781, 12, 250, "Input"],
Cell[12570, 308, 43, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[12638, 313, 30, 0, 59, "Section"],
Cell[12671, 315, 335, 7, 109, "Text"],
Cell[13009, 324, 47, 1, 30, "Input"],
Cell[13059, 327, 891, 19, 290, "Input"],
Cell[13953, 348, 898, 19, 290, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

